@@ -8,8 +8,6 @@ import os
 
 from psycopg2.extras import DictCursor, NamedTupleCursor
 
-import pool
-
 
 class PgSimple(object):
     _connection = None
@@ -19,20 +17,19 @@ class PgSimple(object):
     _cursor_factory = None
     _pool = None
 
-    def __init__(self, log=None, log_fmt=None, nt_cursor=True):
+    def __init__(self, pool, log=None, log_fmt=None, nt_cursor=True):
         self._log = log
         self._log_fmt = log_fmt
         self._cursor_factory = NamedTupleCursor if nt_cursor else DictCursor
-
+        self._pool = pool
         self._connect()
 
     def _connect(self):
         """Connect to the postgres server"""
-        self._pool = pool.get_pool()
         try:
             self._connection = self._pool.get_conn()
             self._cursor = self._connection.cursor(cursor_factory=self._cursor_factory)
-        except Exception, e:
+        except Exception as e:
             self._log_error('postgresql connection failed: ' + e.message)
             raise
 
@@ -116,7 +113,7 @@ class PgSimple(object):
         cols, vals = self._format_insert(data)
         sql = 'INSERT INTO %s (%s) VALUES(%s)' % (table, cols, vals)
         sql += self._returning(returning)
-        cur = self.execute(sql, data.values())
+        cur = self.execute(sql, list(data.values()))
         return cur.fetchone() if returning else cur.rowcount
 
     def update(self, table, data, where=None, returning=None):
@@ -125,7 +122,7 @@ class PgSimple(object):
 
         sql = 'UPDATE %s SET %s' % (table, query)
         sql += self._where(where) + self._returning(returning)
-        cur = self.execute(sql, data.values() + where[1] if where and len(where) > 1 else data.values())
+        cur = self.execute(sql, list(data.values()) + where[1] if where and len(where) > 1 else list(data.values()))
         return cur.fetchall() if returning else cur.rowcount
 
     def delete(self, table, where=None, returning=None):
@@ -143,7 +140,7 @@ class PgSimple(object):
             self._cursor.execute(sql, params)
             if self._log and self._log_fmt:
                 self._log_cursor(self._cursor)
-        except Exception, e:
+        except Exception as e:
             if self._log and self._log_fmt:
                 self._log_error('execute() failed: ' + e.message)
             raise
